==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/autoscaling/kotlin/TrafficSourceAttachment.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.autoscaling.kotlin

import com.pulumi.aws.autoscaling.kotlin.outputs.TrafficSourceAttachmentTrafficSource
import com.pulumi.aws.autoscaling.kotlin.outputs.TrafficSourceAttachmentTrafficSource.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [TrafficSourceAttachment].
 */
@PulumiTagMarker
public class TrafficSourceAttachmentResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: TrafficSourceAttachmentArgs = TrafficSourceAttachmentArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend TrafficSourceAttachmentArgsBuilder.() -> Unit) {
        val builder = TrafficSourceAttachmentArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): TrafficSourceAttachment {
        val builtJavaResource =
            com.pulumi.aws.autoscaling.TrafficSourceAttachment(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return TrafficSourceAttachment(builtJavaResource)
    }
}

/**
 * Attaches a traffic source to an Auto Scaling group.
 * > **NOTE on Auto Scaling Groups, Attachments and Traffic Source Attachments:** Pulumi provides standalone Attachment (for attaching Classic Load Balancers and Application Load Balancer, Gateway Load Balancer, or Network Load Balancer target groups) and Traffic Source Attachment (for attaching Load Balancers and VPC Lattice target groups) resources and an Auto Scaling Group resource with `load_balancers`, `target_group_arns` and `traffic_source` attributes. Do not use the same traffic source in more than one of these resources. Doing so will cause a conflict of attachments. A `lifecycle` configuration block can be used to suppress differences if necessary.
 * ## Example Usage
 * ### Basic Usage
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.autoscaling.TrafficSourceAttachment;
 * import com.pulumi.aws.autoscaling.TrafficSourceAttachmentArgs;
 * import com.pulumi.aws.autoscaling.inputs.TrafficSourceAttachmentTrafficSourceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var example = new TrafficSourceAttachment("example", TrafficSourceAttachmentArgs.builder()
 *             .autoscalingGroupName(aws_autoscaling_group.example().id())
 *             .trafficSource(TrafficSourceAttachmentTrafficSourceArgs.builder()
 *                 .identifier(aws_lb_target_group.example().arn())
 *                 .type("elbv2")
 *                 .build())
 *             .build());
 *     }
 * }
 * ```
 */
public class TrafficSourceAttachment internal constructor(
    override val javaResource: com.pulumi.aws.autoscaling.TrafficSourceAttachment,
) : KotlinCustomResource(javaResource, TrafficSourceAttachmentMapper) {
    /**
     * The name of the Auto Scaling group.
     */
    public val autoscalingGroupName: Output<String>
        get() = javaResource.autoscalingGroupName().applyValue({ args0 -> args0 })

    /**
     * The unique identifiers of a traffic sources.
     */
    public val trafficSource: Output<TrafficSourceAttachmentTrafficSource>?
        get() = javaResource.trafficSource().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 -> toKotlin(args0) })
            }).orElse(null)
        })
}

public object TrafficSourceAttachmentMapper : ResourceMapper<TrafficSourceAttachment> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.aws.autoscaling.TrafficSourceAttachment::class == javaResource::class

    override fun map(javaResource: Resource): TrafficSourceAttachment =
        TrafficSourceAttachment(javaResource as com.pulumi.aws.autoscaling.TrafficSourceAttachment)
}

/**
 * @see [TrafficSourceAttachment].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [TrafficSourceAttachment].
 */
public suspend fun trafficSourceAttachment(
    name: String,
    block: suspend TrafficSourceAttachmentResourceBuilder.() -> Unit,
): TrafficSourceAttachment {
    val builder = TrafficSourceAttachmentResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [TrafficSourceAttachment].
 * @param name The _unique_ name of the resulting resource.
 */
public fun trafficSourceAttachment(name: String): TrafficSourceAttachment {
    val builder = TrafficSourceAttachmentResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/autoscaling/kotlin/TrafficSourceAttachment.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.autoscaling.kotlin

import com.pulumi.aws.autoscaling.kotlin.outputs.TrafficSourceAttachmentTrafficSource
import com.pulumi.aws.autoscaling.kotlin.outputs.TrafficSourceAttachmentTrafficSource.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [TrafficSourceAttachment].
 */
@PulumiTagMarker
public class TrafficSourceAttachmentResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: TrafficSourceAttachmentArgs = TrafficSourceAttachmentArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend TrafficSourceAttachmentArgsBuilder.() -> Unit) {
        val builder = TrafficSourceAttachmentArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): TrafficSourceAttachment {
        val builtJavaResource =
            com.pulumi.aws.autoscaling.TrafficSourceAttachment(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return TrafficSourceAttachment(builtJavaResource)
    }
}

/**
 * Attaches a traffic source to an Auto Scaling group.
 * > **NOTE on Auto Scaling Groups, Attachments and Traffic Source Attachments:** Pulumi provides standalone Attachment (for attaching Classic Load Balancers and Application Load Balancer, Gateway Load Balancer, or Network Load Balancer target groups) and Traffic Source Attachment (for attaching Load Balancers and VPC Lattice target groups) resources and an Auto Scaling Group resource with `load_balancers`, `target_group_arns` and `traffic_source` attributes. Do not use the same traffic source in more than one of these resources. Doing so will cause a conflict of attachments. A `lifecycle` configuration block can be used to suppress differences if necessary.
 * ## Example Usage
 * ### Basic Usage
 * <!--Start PulumiCodeChooser -->
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 * const example = new aws.autoscaling.TrafficSourceAttachment("example", {
 *     autoscalingGroupName: exampleAwsAutoscalingGroup.id,
 *     trafficSource: {
 *         identifier: exampleAwsLbTargetGroup.arn,
 *         type: "elbv2",
 *     },
 * });
 * ```
 * ```python
 * import pulumi
 * import pulumi_aws as aws
 * example = aws.autoscaling.TrafficSourceAttachment("example",
 *     autoscaling_group_name=example_aws_autoscaling_group["id"],
 *     traffic_source={
 *         "identifier": example_aws_lb_target_group["arn"],
 *         "type": "elbv2",
 *     })
 * ```
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using Aws = Pulumi.Aws;
 * return await Deployment.RunAsync(() =>
 * {
 *     var example = new Aws.AutoScaling.TrafficSourceAttachment("example", new()
 *     {
 *         AutoscalingGroupName = exampleAwsAutoscalingGroup.Id,
 *         TrafficSource = new Aws.AutoScaling.Inputs.TrafficSourceAttachmentTrafficSourceArgs
 *         {
 *             Identifier = exampleAwsLbTargetGroup.Arn,
 *             Type = "elbv2",
 *         },
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-aws/sdk/v6/go/aws/autoscaling"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := autoscaling.NewTrafficSourceAttachment(ctx, "example", &autoscaling.TrafficSourceAttachmentArgs{
 * 			AutoscalingGroupName: pulumi.Any(exampleAwsAutoscalingGroup.Id),
 * 			TrafficSource: &autoscaling.TrafficSourceAttachmentTrafficSourceArgs{
 * 				Identifier: pulumi.Any(exampleAwsLbTargetGroup.Arn),
 * 				Type:       pulumi.String("elbv2"),
 * 			},
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.autoscaling.TrafficSourceAttachment;
 * import com.pulumi.aws.autoscaling.TrafficSourceAttachmentArgs;
 * import com.pulumi.aws.autoscaling.inputs.TrafficSourceAttachmentTrafficSourceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var example = new TrafficSourceAttachment("example", TrafficSourceAttachmentArgs.builder()
 *             .autoscalingGroupName(exampleAwsAutoscalingGroup.id())
 *             .trafficSource(TrafficSourceAttachmentTrafficSourceArgs.builder()
 *                 .identifier(exampleAwsLbTargetGroup.arn())
 *                 .type("elbv2")
 *                 .build())
 *             .build());
 *     }
 * }
 * ```
 * ```yaml
 * resources:
 *   example:
 *     type: aws:autoscaling:TrafficSourceAttachment
 *     properties:
 *       autoscalingGroupName: ${exampleAwsAutoscalingGroup.id}
 *       trafficSource:
 *         identifier: ${exampleAwsLbTargetGroup.arn}
 *         type: elbv2
 * ```
 * <!--End PulumiCodeChooser -->
 */
public class TrafficSourceAttachment internal constructor(
    override val javaResource: com.pulumi.aws.autoscaling.TrafficSourceAttachment,
) : KotlinCustomResource(javaResource, TrafficSourceAttachmentMapper) {
    /**
     * The name of the Auto Scaling group.
     */
    public val autoscalingGroupName: Output<String>
        get() = javaResource.autoscalingGroupName().applyValue({ args0 -> args0 })

    /**
     * The unique identifiers of a traffic sources.
     */
    public val trafficSource: Output<TrafficSourceAttachmentTrafficSource>?
        get() = javaResource.trafficSource().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 -> toKotlin(args0) })
            }).orElse(null)
        })
}

public object TrafficSourceAttachmentMapper : ResourceMapper<TrafficSourceAttachment> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.aws.autoscaling.TrafficSourceAttachment::class == javaResource::class

    override fun map(javaResource: Resource): TrafficSourceAttachment =
        TrafficSourceAttachment(javaResource as com.pulumi.aws.autoscaling.TrafficSourceAttachment)
}

/**
 * @see [TrafficSourceAttachment].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [TrafficSourceAttachment].
 */
public suspend fun trafficSourceAttachment(
    name: String,
    block: suspend TrafficSourceAttachmentResourceBuilder.() -> Unit,
): TrafficSourceAttachment {
    val builder = TrafficSourceAttachmentResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [TrafficSourceAttachment].
 * @param name The _unique_ name of the resulting resource.
 */
public fun trafficSourceAttachment(name: String): TrafficSourceAttachment {
    val builder = TrafficSourceAttachmentResourceBuilder()
    builder.name(name)
    return builder.build()
}
